<template>
  <el-bus-crud v-bind="tableConfig" />
</template>

<script>
export default {
  data() {
    return {
      tableConfig: {
        url: 'flower/api/transport/fee/list',
        hasPagination: false,
        dialogNeedRequest: true,
        operationAttrs: {
          width: 150,
          fixed: 'right',
        },
        columns: [
          { label: '运费配置类型', prop: 'typeStr', minWidth: 100 },
          { label: '首重(kg)', prop: 'firstWeight', minWidth: 100 },
          { label: '首重起步价(元)', prop: 'firstWeightFee', minWidth: 100 },
          { label: '续重(kg)', prop: 'addedWeight', minWidth: 100 },
          { label: '续重价(元)', prop: 'addedWeightFee', minWidth: 100 },
          {
            label: '地区',
            formatter: (row) => this.formatDistrict(row),
            minWidth: 400,
          },
        ],
        extraQuery: {
          id: this.$route.params.id,
        },
        extraBody: {
          transportId: this.$route.params.id,
        },
        form: [
          {
            type: 'row',
            span: 12,
            items: [
              {
                label: '运费配置类型：',
                id: 'type',
                type: 'bus-radio',
                el: {
                  code: 'freight_template_type',
                  style: 'width:100%',
                },
                default: '0',
                str: true,
                rules: { required: true, message: '请选择运费配置类型' },
                on: {
                  change: (e, updateForm) => {

                  },
                },
              },
              {
                label: '首重：',
                id: 'firstWeight',
                type: 'input-number',
                el: {
                  precision: 2,
                  min: 0,
                  controls: false,
                },
                unit: 'kg',
                rules: {
                  required: true,
                  message: '请输入首重',
                  trigger: 'blur',
                },
                hidden: (row) => row.type !== '0',
              },
              {
                label: '首重起步价：',
                id: 'firstWeightFee',
                type: 'input-number',
                el: {
                  precision: 2,
                  min: 0,
                  controls: false,
                },
                unit: '元',
                rules: {
                  required: true,
                  message: '请输入首重起步价',
                  trigger: 'blur',
                },
                hidden: (row) => row.type !== '0',
              },
              {
                label: '续重：',
                id: 'addedWeight',
                type: 'input-number',
                el: {
                  precision: 2,
                  min: 0,
                  controls: false,
                },
                unit: 'kg',
                rules: {
                  required: true,
                  message: '请输入续重',
                  trigger: 'blur',
                },
                hidden: (row) => row.type !== '0',
              },
              {
                label: '续重价：',
                id: 'addedWeightFee',
                type: 'input-number',
                el: {
                  precision: 2,
                  min: 0,
                  controls: false,
                },
                unit: '元',
                rules: {
                  required: true,
                  message: '请输入续重价',
                  trigger: 'blur',
                },
                hidden: (row) => row.type !== '0',
              },
              {
                label: '地区：',
                id: 'areas',
                component: 'area-select',
                span: 24,
                forceDisabled: true,
                rules: {
                  required: true,
                  message: '请选择地区',
                },
                hidden: (row) => row.type !== '0',
              },
            ],
          },
        ],
      },
    }
  },
  head() {
    return {
      title: '运费配置',
    }
  },
  methods: {
    formatDistrict(row) {
      if (Array.isArray(row.areas) && row.areas.length > 0) {
        return (
          <div>
            {row.areas.slice(0, 5).map((item) => {
              return (
                <el-tag type="primary" class="mr-4 mb-4">
                  {item.province}-{item.city}
                </el-tag>
              )
            })}
            {row.areas.length > 5 ? (
              <el-tooltip
                placement="top"
                popper-class="freight-popper"
                content={row.areas
                  .map((i) => `${i.province}-${i.city}`)
                  .join('，')}
              >
                <span class="text-primary">查看更多</span>
              </el-tooltip>
            ) : null}
          </div>
        )
      }
      return ''
    },
  },
}
</script>

<style>
.freight-popper {
  max-width: 60%;
}
</style>
